@@ -56,6 +56,9 @@ impl Graph {
             graph: self,
         }
     }
+    pub fn add_vars<'a>(&'a self, vals: &[f64]) -> Vec<Var<'a>> {
+        vals.iter().map(|&x| self.add_var(x)).collect()
+    }
     pub fn zero_grad(&self) {
         self.nodes
             .borrow_mut()
@@ -336,6 +339,30 @@ impl<'a> Display for Var<'a> {
     }
 }
 
+impl<'a> PartialEq for Var<'a> {
+    fn eq(&self, other: &Self) -> bool {
+        self.val.eq(&other.val)
+    }
+}
+
+impl<'a> PartialOrd for Var<'a> {
+    fn partial_cmp(&self, other: &Self) -> Option<std::cmp::Ordering> {
+        self.val.partial_cmp(&other.val)
+    }
+}
+
+impl<'a> PartialEq<f64> for Var<'a> {
+    fn eq(&self, other: &f64) -> bool {
+        self.val.eq(other)
+    }
+}
+
+impl<'a> PartialOrd<f64> for Var<'a> {
+    fn partial_cmp(&self, other: &f64) -> Option<std::cmp::Ordering> {
+        self.val.partial_cmp(other)
+    }
+}
+
 pub trait Gradient<T, S> {
     fn wrt(&self, v: T) -> S;
 }
